-- create and select the database
DROP DATABASE IF EXISTS panex_robno;
CREATE DATABASE panex_robno;

USE panex_robno;
-- create the tables for the database
CREATE TABLE partneri (
  IDpartnera         INT         NOT NULL   AUTO_INCREMENT,
  kodPartnera        VARCHAR(13) NOT NULL,
  nazivPartnera      VARCHAR(70) NOT NULL,
  mjestoSjedista     VARCHAR(60) NOT NULL,
  ulicaBroj          VARCHAR(60) NOT NULL,
  posPretinac        VARCHAR(10) DEFAULT " ", 
  mjestoPoste        VARCHAR(60) NOT NULL,
  brojPoste          VARCHAR(10) NOT NULL,
  sifraOpcine        INT DEFAULT 0,
  sifraZupanije      INT DEFAULT 0, 
  pokrajina          VARCHAR(50) DEFAULT " ",      
  zemlja             INT DEFAULT 385,
  maticniBroj        VARCHAR(13) DEFAULT " ",
  OIB                INT NOT NULL,   
  telefoni           VARCHAR(50) DEFAULT " ",   
  fax                VARCHAR(34) DEFAULT " ",
  brojBankRacuna     VARCHAR(60) DEFAULT " ",
  email              VARCHAR(255) DEFAULT " "  NOT NULL,
  password           VARCHAR(60)  DEFAULT " ", 
  opis               TEXT   NOT NULL,  
  datumOtvaranja     DATETIME NOT NULL,
  datumIzmjene       DATETIME DEFAULT 0,
  tkoJeIzmjenio      VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (IDpartnera),
  UNIQUE INDEX kodPartnera (kodPartnera),
  UNIQUE INDEX email (email)
);
CREATE TABLE narudzbe (
  brojNarudzbe        INT            NOT NULL   AUTO_INCREMENT,
  kodPartnera         VARCHAR(13)    NOT NULL,
  datum               DATETIME       NOT NULL,
  datumPotvrdeOdNas   DATETIME       DEFAULT NULL, 
  nacinPlacanja       VARCHAR(2) NOT NULL, 
  trosakIsporuke      DECIMAL(10,2)  NOT NULL,
  poreznaGrupaIsporuke      VARCHAR(2) DEFAULT "A" NOT NULL,
  PDVisporuke               DECIMAL(6,3)  NOT NULL,
  datumPotvrdeOdKupca DATETIME       DEFAULT NULL, 
  datumOtkazaOdKupca  DATETIME       DEFAULT NULL,
  nacinIsporuke       CHAR(2)        DEFAULT NULL,
  datumIsporuke       DATETIME       DEFAULT NULL,
  vrstaRacuna         INT DEFAULT 0,
-- 0 obicni, 1 R1 racun  
  vrstaKartice        INT            NOT NULL,
  brojKartice         CHAR(16)       NOT NULL,
  vrijediDo           CHAR(7)        NOT NULL,
  komentarNarudzbeKupac  TEXT  DEFAULT NULL, 
  komentarNarudzbeNas    TEXT  DEFAULT NULL,  
  datumOtvaranja      DATETIME NOT NULL,
  datumIzmjene        DATETIME DEFAULT 0,
  tkoJeIzmjenio       VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (brojNarudzbe), 
  INDEX kodPartnera (kodPartnera)
);

CREATE TABLE narudzbe_stavke (
  brojNarudzbe      INT            NOT NULL,
  brojStavke        INT            NOT NULL, 
  kodRobe           VARCHAR(13)    NOT NULL,
  poreznaGrupa      VARCHAR(2) DEFAULT "A" NOT NULL,
  PDV               DECIMAL(6,3)  NOT NULL,
  cijena            DECIMAL(11,3)  NOT NULL,
  popust            DECIMAL(4,2) NOT NULL,  
  kolicina          DECIMAL(11,3)  NOT NULL,
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (brojNarudzbe, brojStavke), 
  INDEX kodRobe (kodRobe)
);

CREATE TABLE maticna_robe (
  kodRobe           CHAR(13)       NOT NULL,
  nazivRobe         VARCHAR(100)   NOT NULL, 
  jedinicaMjere     CHAR(3) NOT NULL,
  cijena            DECIMAL(11,3)  NOT NULL,
  popust            DECIMAL(4,2) NOT NULL,  
  kodGrupe          VARCHAR(13) NOT NULL,
  poreznaGrupa      VARCHAR(2) DEFAULT "A" NOT NULL,
  minZaliha         DECIMAL(11,3)  NOT NULL,
  EANkod            VARCHAR(13) DEFAULT " ",
  brutoTezina       DECIMAL(8,2) DEFAULT 0.00,
  netoTezina        DECIMAL(8,2) DEFAULT 0.00,
  zemljaPorijekla   INT  DEFAULT 0,
  zemljaUvoznik     INT DEFAULT 0,
  proOzRobe         VARCHAR(40)	NOT NULL,
  sklopPoKatalogu   VARCHAR(40) DEFAULT " ",
  stavkaSklopa      VARCHAR(20) DEFAULT " ",
  kodProizvodjaca   VARCHAR(13) DEFAULT " ",
  povratnaNaknada   DECIMAL(3,1) DEFAULT 0,
  robaUsluga        CHAR(1) DEFAULT "R" NOT NULL,
  prikazStanja      CHAR(1) DEFAULT "P" NOT NULL,
  opis              TEXT  NOT NULL, 
  datum_dok         DATETIME NOT NULL,
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (kodRobe), 
  INDEX poKoduGrupeInazivu(kodGrupe, nazivRobe), 
  INDEX poKoduGrupeIcijeni(kodGrupe, cijena),
  UNIQUE INDEX poProOzRobe (proOzRobe)
);

CREATE TABLE robne_grupe (
  kodGrupe        CHAR(13)      NOT NULL,
  nazivGrupe      VARCHAR(255)   NOT NULL,
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (kodGrupe)
);
CREATE TABLE posebna_ponuda (
  kodRobe        CHAR(13)      NOT NULL,
  redniBroj      INT DEFAULT 0,
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (kodRobe)
);
CREATE TABLE stanja (
  kodPoslovnice     CHAR(6)       NOT NULL,
  kodRobe           CHAR(13)      NOT NULL,    
  vrstaProdaje      CHAR(1)       NOT NULL,
  cijena            DECIMAL(11,3)  NOT NULL, 
  stanje            DECIMAL(11,3)  NOT NULL,
--posljednji ulazni dokument  
  vrstaPu           VARCHAR(2) DEFAULT NULL,
  brojPu            INT DEFAULT NULL,
    
  
--posljednji izlazni dokument  
  datumInventure    DATETIME DEFAULT 0,
  kolicinaInventure DECIMAL(11,3)  DEFAULT 0,   
  brojInvStavke     INT DEFAULT 0,
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ",   
  PRIMARY KEY (kodPoslovnice, kodRobe, vrstaProdaje, cijena), 
  INDEX poRobi (kodRobe, kodPoslovnice, vrstaProdaje) 
  );
  
CREATE TABLE poslovnice (
  kodPoslovnice      CHAR(6)    NOT NULL,
  nazivPoslovnice    VARCHAR(60) NOT NULL,
  mjestoSjedista     VARCHAR(60) NOT NULL,
  ulicaBroj          VARCHAR(60) NOT NULL,
  posPretinac        VARCHAR(10) DEFAULT " ", 
  mjestoPoste        VARCHAR(60) NOT NULL,
  brojPoste          VARCHAR(10) NOT NULL,
  sifraOpcine        INT DEFAULT 0,
  sifraZupanije      INT DEFAULT 0, 
  pokrajina          VARCHAR(50) DEFAULT " ",      
  zemlja             INT DEFAULT 385,
  maticniBroj        VARCHAR(20) DEFAULT " ",
  OIB                INT NOT NULL,   
  telefoni           TEXT NOT NULL,   
  fax                VARCHAR(34) DEFAULT " ",
  brojBankRacuna     VARCHAR(60) DEFAULT " ",
  emailAddress       VARCHAR(255) DEFAULT " "  NOT NULL,
  password           VARCHAR(20)  DEFAULT " ", 
  datumOtvaranja     DATETIME NOT NULL,
  datumIzmjene       DATETIME DEFAULT 0,
  tkoJeIzmjenio      VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (kodPoslovnice) 
  
);

CREATE TABLE adrese (
  kodPartnera        VARCHAR(13) NOT NULL,
  mjestoSjedista     VARCHAR(60) NOT NULL,
  ulicaBroj          VARCHAR(60) NOT NULL,
  posPretinac        VARCHAR(10) DEFAULT " ", 
  mjestoPoste        VARCHAR(60) NOT NULL,
  brojPoste          VARCHAR(10) NOT NULL,
  sifraOpcine        INT DEFAULT 0,
  sifraZupanije      INT DEFAULT 0, 
  pokrajina          VARCHAR(50) DEFAULT " ",      
  zemlja             INT DEFAULT 385,
  telefoni           VARCHAR(50) DEFAULT " ",   
  opis               TEXT   NOT NULL,  
  datumOtvaranja     DATETIME NOT NULL,
  datumIzmjene       DATETIME DEFAULT 0,
  tkoJeIzmjenio      VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (kodPartnera)
  );
  
CREATE TABLE administrators (
  kodAdmin          INT            NOT NULL   AUTO_INCREMENT,
  email             VARCHAR(255)   NOT NULL,
  lozinka           VARCHAR(255)   NOT NULL,
  ime               VARCHAR(255)   NOT NULL,
  prezime           VARCHAR(255)   NOT NULL,
  prioritet         INT DEFAULT 6,
--0 do 4 administratori baze programeri, 5 do 9 korisnici, 5 administratori korisnici, 6 prodavači 
--najviši prioritet 0, najnizi 9, visi prioritet moze vidjeti nize i mjenjati ih
--isti prioritet može vidjeti i druge iste prioritete ali ih ne moze mjenjati(samo sebe moze mjenjati)
--samo viši prioritet moze mjenjati nize 
--pocetno otvaranje sa pocetnom lozinkom za korisnike mogu samo prioriteti 0 - 4
--a ostali mogu nakon toga promjeniti samo svoju lozinku kada upadnu s tom pocetnom lozinkom 
  baze_za_korisnika    VARCHAR(255),
--baze korisnika s kojima korisnik moze raditi npr. panex_robno_AGM,panex_OD_AGM
--prva baza se defoultno otvara a ostale se otvaraju iz menija prve 
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (kodAdmin)
);
CREATE TABLE dokumenti (
 proda VARCHAR(5)   NOT NULL, 
 vrsdo VARCHAR(2)   NOT NULL,
 proin VARCHAR(6)   NOT NULL,  
 zapis VARCHAR(2)   NOT NULL,
 brodo INT          NOT NULL,
 verzi VARCHAR(3)   NOT NULL,
  kodPartnera         VARCHAR(13) NOT NULL,
  DVO                 DATETIME    NOT NULL,
  valuta              DATETIME    NOT NULL, 
   dani_odgode_pl     INT DEFAULT 0,
  datum_zakljucavanja DATETIME    DEFAULT NULL,
  datum_racuna        DATETIME    DEFAULT NULL,  
  datum_narudzbe      DATETIME    DEFAULT NULL,
  broj_narudzbe       VARCHAR(30) DEFAULT NULL,
  PDVstatus           CHAR(1) DEFAULT " ",
  casas_sconto         DECIMAL(11,3)  NOT NULL,
   abs_casas_sconto    CHAR(1) DEFAULT " ",
   dani_za_casa_sconto INT DEFAULT 0,
  ref_prod             VARCHAR(13) NOT NULL,
  komercijalista       VARCHAR(13) NOT NULL,
  komentar  TEXT  DEFAULT NULL, 
  datumOtvaranja      DATETIME NOT NULL,
  datumIzmjene        DATETIME DEFAULT 0,
  tkoJeIzmjenio       VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY PRIMARY KEY (proda, vrsdo, proin, zapis, brodo, verzi) 
  INDEX kodPartnera (kodPartnera)
);

CREATE TABLE dokumenti_stavke (
 proda VARCHAR(5)   NOT NULL, 
 vrsdo VARCHAR(2)   NOT NULL,
 proin VARCHAR(6)   NOT NULL,  
 zapis VARCHAR(2)   NOT NULL,
 brodo INT          NOT NULL,
 verzi VARCHAR(3)   NOT NULL,
 brojStavke INT     NOT NULL, 
  kodRobe           VARCHAR(13)    NOT NULL,
  vrsta_prodaje     CHAR(1) DEFAULT "0",
  cijena            DECIMAL(11,3)  NOT NULL,
  cijena2_za_intfak DECIMAL(11,3)  NOT NULL,
  kolicina          DECIMAL(11,3)  NOT NULL,
  rabat_popust             DECIMAL(11,3)  NOT NULL,
   abs_rabat_popust        CHAR(1) DEFAULT " ",
  rabat_popust_na_kol      DECIMAL(11,3)  NOT NULL,
   abs_rabat_popust_na_kol CHAR(1) DEFAULT " ",
  PDVkod            VARCHAR(2) DEFAULT "A" NOT NULL,
  PDV               DECIMAL(6,3)  NOT NULL,
  ukalkuliarni_PDV  DECIMAL(6,3)  NOT NULL,
  povratna_naknada  DECIMAL(4,2) DEFAULT 0,
  nabavna_cijena    DECIMAL(11,3)  NOT NULL, 
  marza             DECIMAL(11,3)  NOT NULL,
   abs_marza        VARCHAR(1) DEFAULT " ",
  zavisni_troskovi  DECIMAL(11,3)  NOT NULL,
   abs_zav_tr       VARCHAR(1) DEFAULT " ",
  DVO               DATETIME NOT NULL, 
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (proda, vrsdo, proin, zapis, brodo, verzi, brojStavke), 
  INDEX kartica (proda, kodRobe, DVO)
);
CREATE TABLE PDV_stope (
 PDVkod      VARCHAR(2) DEFAULT "A",
  pdv        DECIMAL(6,3)  NOT NULL,
  datumOtvaranja    DATETIME NOT NULL,
  datumIzmjene      DATETIME DEFAULT 0,
  tkoJeIzmjenio     VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (PDVkod)
);

-- Insert data into the tables
GRANT SELECT, INSERT, UPDATE, DELETE
ON *
TO panex_javniKoris@localhost
IDENTIFIED BY 'a83bmi';


-- Create a user 
GRANT SELECT, INSERT, UPDATE, DELETE
ON *
TO panex@localhost
IDENTIFIED BY 'c48kt3';

