<?php
function get_gk() {
    global $db;
    $query = 'SELECT * FROM gk_stavke'; 
    try {
        $statement = $db->prepare($query);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}
function get_gk_stavku($brojTemeljnice,$brojStavke) {
    global $db;
    $query = '
        SELECT *
        FROM gk_stavke
        WHERE brojTemeljnice = :brojTemeljnice
        AND brojStavke=:brojStavke';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':brojTemeljnice', $brojTemeljnice);
        $statement->bindValue(':brojStavke', $brojStavke);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_gk_po_temeljnicama($parametri) {
    global $db;
    $query = "
select 
gk.brojTemeljnice, gk.vrsDo, vd.nazivDokumenta, vd.oznakaDokumenta, gk.brojIzvoda, 
sum(iznosDug) as duguje, sum(iznosPot) as potrazuje, count(brojStavke) as stavaka
from gk_stavke as gk
left outer join vrste_dokumenata as vd on vd.vrsDo=gk.vrsDo 
where (gk.konto=:konto or trim(:konto)='')
and (gk.kodPartnera=:kodPartnera or trim(:kodPartnera)='')
and (gk.vrsDo=:vrsDo or trim(:vrsDo)='')
and (gk.DVO>=:DVOod or trim(:DVOod)='')
and (gk.DVO<=:DVOdo or trim(:DVOdo)='')
and (:prikazuje='' or (:prikazuje='F' and trim(gk.kodPartnera)='') or (:prikazuje='S' and trim(gk.kodPartnera)<>''))
and  (
    ((:kojiIznos='D' or :kojiIznos='') and 
     ((trim(:iznosOd)='' or IznosDug>=:iznosOd) and (trim(:iznosDo)='' or iznosDug<=:iznosDo)))
 or ((:kojiIznos='P' or :kojiIznos='') and  
     ((trim(:iznosOd)='' or IznosPot>=:iznosOd) and (trim(:iznosDo)='' or iznosPot<=:iznosDo)))
 or (:kojiIznos='O' and 
     ((trim(:iznosOd)='' or iznosOtv>=:iznosOd) and (trim(:iznosDo)='' or iznosOtv<=:iznosDo)))
)
group by `brojTemeljnice`, vrsDo, `brojIzvoda` 
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrsDo', $parametri['vrsDo']);
        $statement->bindValue(':konto', $parametri['konto']);
        $statement->bindValue(':kodPartnera', $parametri['kodPartnera']);
        if(trim($parametri['DVOod'])=='')
            $DVOod='';
        else {
            $d1=new DateTime($parametri['DVOod']);
            $DVOod = $d1->format('Y-m-d H:i:s');
        }
        $statement->bindValue(':DVOod', $DVOod);
        if(trim($parametri['DVOdo'])=='')
            $DVOdo='';
        else {
            $d1=new DateTime($parametri['DVOdo']);
            $DVOdo = $d1->format('Y-m-d H:i:s');
        }
        $statement->bindValue(':DVOdo', $DVOdo);
        $statement->bindValue(':prikazuje', $parametri['prikazuje']);
        $statement->bindValue(':kojiIznos', $parametri['kojiIznos']);
        $statement->bindValue(':iznosOd', str_replace(',', '.', $parametri['iznosOd']));
        $statement->bindValue(':iznosDo', str_replace(',', '.', $parametri['iznosDo']));
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_gk_lista_konto_partner($parametri) {
    global $db;
    $query = "
select *
from
(
select gk.konto, k.nazivKonta, gk.kodPartnera, '' as nazivPartnera, sum(iznosDug) as duguje, sum(iznosPot) as potrazuje
, if(trim(gk.kodPartnera)<>'' and trim(:DVOdo)<>'', fnIznosOtvoreno(gk.konto, gk.vrsDo, gk.broDo, gk.kodPartnera, :DVOdo), gk.iznosOtv) as otvoreno
from gk_stavke as gk
join konta as k on k.konto=gk.konto
where (gk.konto like :konto or trim(:konto)='')
and (gk.kodPartnera=:kodPartnera or trim(:kodPartnera)='')
and (gk.vrsDo=:vrsDo or trim(:vrsDo)='')
and (gk.DVo>=:DVOod or trim(:DVOod)='')
and (gk.DVO<=:DVOdo or trim(:DVOdo)='')
and (:prikazuje='' or (:prikazuje='F' and trim(gk.kodPartnera)='') or (:prikazuje='S' and trim(gk.kodPartnera)<>''))
and  (
    ((:kojiIznos='D' or :kojiIznos='') and 
     ((trim(:iznosOd)='' or IznosDug>=:iznosOd) and (trim(:iznosDo)='' or iznosDug<=:iznosDo)))

 or ((:kojiIznos='P' or :kojiIznos='') and  
     ((trim(:iznosOd)='' or IznosPot>=:iznosOd) and (trim(:iznosDo)='' or iznosPot<=:iznosDo)))
 or :kojiIznos='O'        
)       
group by gk.konto, gk.kodPartnera, nazivKonta, nazivPartnera
) as g
where (:forma='uzmi_fin_kartica' or otvoreno<>0)
and (:kojiIznos<>'O' 
    or ((trim(:iznosOd)='' or otvoreno>=:iznosOd) and (trim(:iznosDo)='' or otvoreno<=:iznosDo)))
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrsDo', $parametri['vrsDo']);
        $statement->bindValue(':konto', trim($parametri['konto']).'%');
        $statement->bindValue(':kodPartnera', $parametri['kodPartnera']);
        if(trim($parametri['DVOod'])=='')
            $DVOod='';
        else {
            $d1=new DateTime($parametri['DVOod']);
            $DVOod = $d1->format('Y-m-d H:i:s');
        }
        $statement->bindValue(':DVOod', $DVOod);
        if(trim($parametri['DVOdo'])=='')
            $DVOdo='';
        else {
            $d1=new DateTime($parametri['DVOdo']);
            $DVOdo = $d1->format('Y-m-d H:i:s');
        }
        $statement->bindValue(':DVOdo', $DVOdo);
        $statement->bindValue(':prikazuje', $parametri['prikazuje']);
        $statement->bindValue(':forma', $parametri['forma']);
        $statement->bindValue(':kojiIznos', $parametri['kojiIznos']);
        $statement->bindValue(':iznosOd', str_replace(',', '.', $parametri['iznosOd']));
        $statement->bindValue(':iznosDo', str_replace(',', '.', $parametri['iznosDo']));
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_kartica_za_konto_partner($parametri,$konto,$kodPartnera) {
    global $db;
    $query = "
select *
from
(
select gk.*, vd.nazivDokumenta, vd.oznakaDokumenta
, if(trim(gk.kodPartnera)<>'' and trim(:DVOdo)<>'', fnIznosOtvoreno(gk.konto, gk.vrsDo, gk.broDo, gk.kodPartnera, :DVOdo), iznosOtv) as otvoreno
from gk_stavke as gk
left outer join vrste_dokumenata as vd on vd.vrsDo=gk.vrsDo 
where (gk.konto=:konto or trim(:konto)='')
and (gk.kodPartnera=:kodPartnera or trim(:kodPartnera)='')
and (gk.vrsDo=:vrsDo or trim(:vrsDo)='')
and (gk.DVO>=:DVOod or trim(:DVOod)='')
and (gk.DVO<=:DVOdo or trim(:DVOdo)='')
and (:prikazuje='' or (:prikazuje='F' and trim(gk.kodPartnera)='') or (:prikazuje='S' and trim(gk.kodPartnera)<>''))
and  (
    ((:kojiIznos='D' or :kojiIznos='') and 
     ((trim(:iznosOd)='' or IznosDug>=:iznosOd) and (trim(:iznosDo)='' or iznosDug<=:iznosDo)))

 or ((:kojiIznos='P' or :kojiIznos='') and  
     ((trim(:iznosOd)='' or IznosPot>=:iznosOd) and (trim(:iznosDo)='' or iznosPot<=:iznosDo)))
 or :kojiIznos='O'               
)
order by gk.konto, gk.kodPartnera, DVO
) as g
where (:forma='uzmi_fin_kartica' or otvoreno<>0)
and (:kojiIznos<>'O' 
    or ((trim(:iznosOd)='' or otvoreno>=:iznosOd) and (trim(:iznosDo)='' or otvoreno<=:iznosDo)))
;        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrsDo', $parametri['vrsDo']);
        $statement->bindValue(':konto', $konto);
        $statement->bindValue(':kodPartnera', $kodPartnera);
        if(trim($parametri['DVOod'])=='')
            $DVOod='';
        else {
            $d1=new DateTime($parametri['DVOod']);
            $DVOod = $d1->format('Y-m-d H:i:s');
        }
        $statement->bindValue(':DVOod', $DVOod);
        if(trim($parametri['DVOdo'])=='')
            $DVOdo='';
        else {
            $d1=new DateTime($parametri['DVOdo']);
            $DVOdo = $d1->format('Y-m-d H:i:s');
        }
        $statement->bindValue(':DVOdo', $DVOdo);
        $statement->bindValue(':prikazuje', $parametri['prikazuje']);
        $statement->bindValue(':forma', $parametri['forma']);
        $statement->bindValue(':kojiIznos', $parametri['kojiIznos']);
        $statement->bindValue(':iznosOd', str_replace(',', '.', $parametri['iznosOd']));
        $statement->bindValue(':iznosDo', str_replace(',', '.', $parametri['iznosDo']));
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_gk_pdv($brojTemeljnice,$brojStavke) {
    global $db;
    $query = '
        SELECT *
        FROM gk_pdv
        WHERE brojTemeljnice = :brojTemeljnice
        AND brojStavke=:brojStavke';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':brojTemeljnice', $brojTemeljnice);
        $statement->bindValue(':brojStavke', $brojStavke);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}
function get_gk_dupli_dokument($slog) {
    global $db;
    $query = " 
        SELECT * 
        FROM gk_stavke
        WHERE konto=:konto AND vrsDo=:vrsDo AND broDo=:broDo AND brojTemeljnice<>:brojTemeljnice -- AND kodPartnera<>:kodPartnera
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':brojTemeljnice', $slog['brojTemeljnice']);
        $statement->bindValue(':vrsDo', $slog['vrsDo']);
        $statement->bindValue(':broDo', $slog['broDo']);
        $statement->bindValue(':konto', $slog['konto']);
        $statement->bindValue(':kodPartnera', $slog['kodPartnera']);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}
function get_gk_temeljnicu($brojTemeljnice,$vrsDo,$brojIzvoda) {
    global $db;
    $query = " 
        SELECT *
        FROM gk_stavke
        WHERE brojTemeljnice = :brojTemeljnice
        AND (vrsDo=:vrsDo OR :vrsDo='0')
        AND (brojIzvoda=:brojIzvoda OR :brojIzvoda='0')
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':brojTemeljnice', $brojTemeljnice);
        $statement->bindValue(':vrsDo', $vrsDo);
        $statement->bindValue(':brojIzvoda', $brojIzvoda);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function add_gk_stavku($slog) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $query = "
        INSERT INTO gk_stavke
        (
            brojTemeljnice, 
            brojStavke,
            konto,
            kodPartnera,
            pozivNaBroj,
            vrsDo,
            broDo,
            brojIzvoda,
            DVO,
            valuta, 
            iznosDug,
            iznosPot,
            iznosOtv,
            brojDobRacuna,
            vrstaRacuna,
            PDVstatus,
            opisKnjizenja,
            datumOtvaranja,
            tkoJeIzmjenio
        )
        VALUES
        (
            :brojTemeljnice, 
            :brojStavke,
            :konto,
            :kodPartnera,
            :pozivNaBroj,
            :vrsDo,
            :broDo,
            :brojIzvoda,
            :DVO,
            :valuta, 
            :iznosDug,
            :iznosPot,
            :iznosOtv,
            :brojDobRacuna,
            :vrstaRacuna,
            :PDVstatus,
            :opisKnjizenja,
            NOW(), 
            :email_user 
        )";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':brojTemeljnice', $slog['brojTemeljnice']);
        $statement->bindValue(':brojStavke', $slog['brojStavke']);
        $statement->bindValue(':konto', $slog['konto']);
        $statement->bindValue(':kodPartnera', $slog['kodPartnera']);
        $statement->bindValue(':pozivNaBroj', $slog['pozivNaBroj']);
        $statement->bindValue(':vrsDo', $slog['vrsDo']);
        $statement->bindValue(':broDo', $slog['broDo']);
        $statement->bindValue(':brojIzvoda', $slog['brojIzvoda']);

        $d1=new DateTime($slog['DVO']);
        $datum = $d1->format('Y-m-d H:i:s');
        $statement->bindValue(':DVO', $datum);
        
        if(trim($slog['valuta'])=='')
            $statement->bindValue(':valuta', null, PDO::PARAM_NULL);   
        else 
        {
            $d1=new DateTime($slog['valuta']);
            $datum = $d1->format('Y-m-d H:i:s');
            $statement->bindValue(':valuta', $datum);
        }
        $statement->bindValue(':iznosDug', str_replace(',', '.',$slog['iznosDug']));
        $statement->bindValue(':iznosPot', str_replace(',', '.', $slog['iznosPot']));
        $statement->bindValue(':iznosOtv', str_replace(',', '.', $slog['iznosDug']+$slog['iznosPot']));
        $statement->bindValue(':brojDobRacuna', $slog['brojDobRacuna']);
        //$statement->bindValue(':iznosPdv', $slog['iznosPdv']);
        $statement->bindValue(':vrstaRacuna', $slog['vrstaRacuna']);
        $statement->bindValue(':PDVstatus', $slog['PDVstatus']);
        //$statement->bindValue(':neoporezivIznos', $slog['neoporezivIznos']);
        $statement->bindValue(':opisKnjizenja', $slog['opisKnjizenja']);
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();
        //return $poreznaGrupa;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
        return;
    }
    add_pdv_stavku($slog);
}    

function add_pdv_stavku($slog) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    if(isset($_SESSION['temeljnice'][$slog['brojTemeljnice']][$slog['brojIzvoda']][$slog['brojStavke']-1]['gk_pdv'])) {
        $query = "
        INSERT INTO gk_pdv
        (
            brojTemeljnice, 
            brojStavke,
            poreznaGrupa,
            stopa,
            osnovica,
            iznosPDV,
            datumOtvaranja,
            tkoJeIzmjenio
        )
        VALUES
        (
            :brojTemeljnice, 
            :brojStavke,
            :poreznaGrupa,
            :stopa,
            :osnovica,
            :iznosPDV,
            NOW(), 
            :email_user 
        )";
        try {
            $statement = $db->prepare($query);
            $statement->bindValue(':brojTemeljnice', $slog['brojTemeljnice']);
            $statement->bindValue(':brojStavke', $slog['brojStavke']);
            foreach ($_SESSION['temeljnice'][$slog['brojTemeljnice']][$slog['brojIzvoda']][$slog['brojStavke']-1]['gk_pdv'] as $gk_pdv) {
                if((float)str_replace(',', '.', $gk_pdv['osnovica'])==0)
                    continue;
                $statement->bindValue(':poreznaGrupa', $gk_pdv['poreznaGrupa']);
                $statement->bindValue(':stopa', $gk_pdv['stopa']);
                $statement->bindValue(':osnovica', str_replace(',', '.', $gk_pdv['osnovica']));
                $statement->bindValue(':iznosPDV', str_replace(',', '.', $gk_pdv['iznosPDV']));
                $statement->bindValue(':email_user', $email_user);
                $statement->execute();
                $statement->closeCursor();
            }
        } catch (PDOException $e) {
            $error_message = 'Tablica: gk_pdv <br>'.$e->getMessage();
            display_db_error($error_message);
        }
    }
}

function update_gk_stavku($slog) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $query = "
        UPDATE gk_stavke
        SET
            konto=:konto,
            kodPartnera=:kodPartnera,
            pozivNaBroj=:pozivNaBroj,
            vrsDo=:vrsDo,
            broDo=:broDo,
            brojIzvoda=:brojIzvoda,
            DVO=:DVO,
            valuta=:valuta, 
            iznosDug=:iznosDug,
            iznosPot=:iznosPot,
            iznosOtv=:iznosOtv,
            brojDobRacuna=:brojDobRacuna,
            vrstaRacuna=:vrstaRacuna,
            PDVstatus=:PDVstatus,
            opisKnjizenja=:opisKnjizenja,
            datumIzmjene=NOW(),
            tkoJeIzmjenio=:email_user
        WHERE 
            brojTemeljnice=:brojTemeljnice 
            AND brojStavke=:brojStavke
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':brojTemeljnice', $slog['brojTemeljnice']);
        $statement->bindValue(':brojStavke', $slog['brojStavke']);
        $statement->bindValue(':konto', $slog['konto']);
        $statement->bindValue(':kodPartnera', $slog['kodPartnera']);
        $statement->bindValue(':pozivNaBroj', $slog['pozivNaBroj']);
        $statement->bindValue(':vrsDo', $slog['vrsDo']);
        $statement->bindValue(':broDo', $slog['broDo']);
        $statement->bindValue(':brojIzvoda', $slog['brojIzvoda']);

        $d1=new DateTime($slog['DVO']);
        $datum = $d1->format('Y-m-d H:i:s');
        $statement->bindValue(':DVO', $datum);
        
        if(trim($slog['valuta'])=='')
            $statement->bindValue(':valuta', null, PDO::PARAM_NULL);   
        else 
        {
            $d1=new DateTime($slog['valuta']);
            $datum = $d1->format('Y-m-d H:i:s');
            $statement->bindValue(':valuta', $datum);
        }
        $statement->bindValue(':iznosDug', str_replace(',', '.',$slog['iznosDug']));
        $statement->bindValue(':iznosPot', str_replace(',', '.', $slog['iznosPot']));
        $statement->bindValue(':iznosOtv', str_replace(',', '.', $slog['iznosDug']+$slog['iznosPot']));
        $statement->bindValue(':brojDobRacuna', $slog['brojDobRacuna']);
        //$statement->bindValue(':iznosPdv', $slog['iznosPdv']);
        $statement->bindValue(':vrstaRacuna', $slog['vrstaRacuna']);
        $statement->bindValue(':PDVstatus', $slog['PDVstatus']);
        //$statement->bindValue(':neoporezivIznos', $slog['neoporezivIznos']);
        $statement->bindValue(':opisKnjizenja', $slog['opisKnjizenja']);
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
        return;
    }
    delete_gk_pdv_stavku($slog["brojTemeljnice"], $slog["brojStavke"]);
    add_pdv_stavku($slog);
}    

function update_gk_iznosOtv($vrsDo, $broDo, $konto, $kodPartnera, $iznosOtv) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $query = "
        UPDATE gk_stavke
        SET
            iznosOtv=:iznosOtv,
            datumIzmjene=NOW(),
            tkoJeIzmjenio=:email_user
        WHERE 
            konto=:konto AND kodPartnera=:kodPartnera AND vrsDo=:vrsDo AND broDo=:broDo
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrsDo', $vrsDo);
        $statement->bindValue(':broDo', $broDo);
        $statement->bindValue(':konto', $konto);
        $statement->bindValue(':kodPartnera', $kodPartnera);
        $statement->bindValue(':iznosOtv', $iznosOtv);
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
        return;
    }
}    

function  knjizi_temeljnicu(&$temeljnica) {
    //brisi_temeljnicu($temeljnica[0]['brojTemeljnice']);
    $i=0;
    foreach ($temeljnica as $slog) {
        if($slog['izmjenjeno']) {
            $stavka=get_gk_stavku($slog["brojTemeljnice"], $slog["brojStavke"]);
            if(is_array($stavka))
                update_gk_stavku($slog);
            else
                add_gk_stavku($slog);
            if(isset($slog['noveVeze'])) {
                zatvaranjeStavaka($slog['noveVeze']['lijeviDok'], $slog['noveVeze']['vezniDok'], $slog['noveVeze']['iznosVeza']);
                unset($slog['noveVeze']);
            }
            $temeljnica[$i]['izmjenjeno']=false;
        }
        $i++;
    }
}

function brisi_temeljnicu($brojTemeljnice) {
    global $db;
    $query = '
        DELETE
        FROM gk_stavke
        WHERE brojTemeljnice = :brojTemeljnice';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':brojTemeljnice', $brojTemeljnice);
        $statement->execute();
    } catch (PDOException $e) {
        $error_message = 'Tablica: gk_pdv <br>'.$e->getMessage();
        display_db_error($error_message);
        return;
    }
    $query = '
        DELETE
        FROM gk_pdv
        WHERE brojTemeljnice = :brojTemeljnice';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':brojTemeljnice', $brojTemeljnice);
        $statement->execute();
    }
    catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function delete_gk_pdv_stavku($brojTemeljnice, $brojStavke) {
    global $db;
    $query = '
        DELETE
        FROM gk_pdv
        WHERE brojTemeljnice = :brojTemeljnice
        AND brojStavke = :brojStavke';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':brojTemeljnice', $brojTemeljnice);
        $statement->bindValue(':brojStavke', $brojStavke);
        $statement->execute();
    } catch (PDOException $e) {
        $error_message = 'Tablica: gk_pdv <br>'.$e->getMessage();
        display_db_error($error_message);
        return;
    }
}    

function delete_gk_stavku($brojTemeljnice, $brojStavke) {
    global $db;
    delete_gk_pdv_stavku($brojTemeljnice, $brojStavke);
    $query = '
        DELETE
        FROM gk_stavke
        WHERE brojTemeljnice = :brojTemeljnice
        AND brojStavke = :brojStavke';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':brojTemeljnice', $brojTemeljnice);
        $statement->bindValue(':brojStavke', $brojStavke);
        $statement->execute();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
    
}

function get_URA_knj($proda, $DVOod, $DVOdo, $poSkladistima='N',$kodPartnera='',$PDVstatus='S') {
    global $db;
    
    $query = "
select 
if(:poSkladistima='D',
if(locate('-',broDo)>0,SUBSTRING_INDEX(broDo,'-',1),'zz'),'') as proda,
s.`brojTemeljnice`,
s.`brojStavke`,
s.broDo,
s.`DVO`,
s.`kodPartnera`,
if(s.`iznosPot`<>0,s.`iznosPot`, s.`iznosDug`) as iznosSPDVom,
pp.nazivPartnera,
pp.ulicaBroj,
pp.mjestoSjedista,
pp.OIB
from gk_stavke as s
left outer join partner as pp on pp.kodPartnera=s.kodPartnera
where vrsDo in ('10','11','12')
and trim(s.kodPartnera)<>''
and s.DVO between :DVOOd and :DVODo
and (s.kodPartnera=:kodPartnera or trim(:kodPartnera)='')
and (PDVStatus=:PDVStatus or :PDVStatus ='S') 
and (s.broDo like :proda or trim(:proda)='' or trim(:proda)='0')
order by
proda,
DVO,
broDo
          ";

    $DVO_o = new DateTime($DVOod);
    $DVO_o2 = new DateTime($DVOdo);

    $statement = $db->prepare($query);
    // /*
    if($proda!='0')
        $proda=trim($proda).'%';
    $statement->bindValue(':proda', $proda);
    $statement->bindValue(':DVOOd', $DVO_o->format("Y-m-d H:i:s"));
    $statement->bindValue(':DVODo', $DVO_o2->format("Y-m-d H:i:s"));
    $statement->bindValue(':poSkladistima', $poSkladistima);
    $statement->bindValue(':kodPartnera', $kodPartnera);
    $statement->bindValue(':PDVStatus', $PDVstatus);
    
     // */
    $statement->execute();
    $knjiga= $statement->fetchAll();
    $statement->closeCursor();
    return $knjiga;
    
}

function get_URA_stopa($brojTemeljnice, $brojStavke, $stopa) {
    global $db;
    
    $query = "
        select s.*, p.`PDV` 
        from gk_pdv as s
        inner join porezi as p on p.`poreznaGrupa`=s.`poreznaGrupa`
        where brojTemeljnice=:brojTemeljnice 
        and brojStavke=:brojStavke
        and PDV=:PDV
          ";

    $statement = $db->prepare($query);
    // /*
    $statement->bindValue(':brojTemeljnice', $brojTemeljnice);
    $statement->bindValue(':brojStavke', $brojStavke);
    $statement->bindValue(':PDV', $stopa);
     // */
    $statement->execute();
    $knjiga= $statement->fetch();
    $statement->closeCursor();
    return $knjiga;
    
}

function get_gk_max_brojStavke($brojTemeljnice) {
    global $db;
    $query = "
        select ifnull(max(brojStavke),0) maxBrojStavke 
        from gk_stavke
        where brojTemeljnice=:brojTemeljnice
    ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':brojTemeljnice', $brojTemeljnice);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result['maxBrojStavke'];
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_gk_za_zatvaranje($konto, $kodPartnera, $brojTemeljnice,$brojStavke) {
    global $db;
    $query = "
        select gk.*,
        vd.oznakaDokumenta,
        if(gk.`iznosDug`<>0, gk.`iznosOtv`,0) as iznosOtvDug,
        if(gk.`iznosPot`<>0, gk.`iznosOtv`,0) as iznosOtvPot
        from gk_stavke as gk
        left outer join vrste_dokumenata as vd on vd.vrsDo=gk.vrsDo
        where konto=:konto
        and kodPartnera=:kodPartnera
        and not (gk.brojTemeljnice=:brojTemeljnice and gk.brojStavke=:brojStavke)
        and gk.iznosOtv<>0
        order by gk.valuta, gk.broDo        
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':konto', $konto);
        $statement->bindValue(':kodPartnera', $kodPartnera);
        $statement->bindValue(':brojTemeljnice', $brojTemeljnice);
        $statement->bindValue(':brojStavke', $brojStavke);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}
