<?php
function add_veze($brojTemeljnice, $brojStavke, $vBrojTemeljnice, $vBrojStavke, $iznosVeze) {
    global $db;
    $dokument=get_gk_stavku($brojTemeljnice, $brojStavke);
    $vezniDokument=get_gk_stavku($vBrojTemeljnice, $vBrojStavke);
    //iznos veze se upisuje s predznakom lijevog dokumenta
    $predznakVeze=round($iznosVeze/abs($iznosVeze),0);  //round radim ako slučajno rezultat nije 1 npr. 1.00000003 ili 0.99999998
    $predznakDokumenta=round($dokument['iznosOtv']/abs($dokument['iznosOtv']),0);
    if($predznakVeze!=$predznakDokumenta)
        $iznosVeze=-$iznosVeze;
    $email_user = $_SESSION['admin']['email'];
    $query = "
        INSERT INTO veze
        (
            konto,
            kodPartnera,
            vrsDo,
            broDo,
            vKonto,
            vKodPartnera,
            vVrsDo,
            vBroDo, 
            iznosVeze,
            datumOtvaranja,
            tkoJeIzmjenio
        )
        VALUES
        (
            :konto,
            :kodPartnera,
            :vrsDo,
            :broDo,
            :vKonto,
            :vKodPartnera,
            :vVrsDo,
            :vBroDo, 
            :iznosVeze,                                                                   
            NOW(), 
            :email_user 
        )";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':konto', $dokument['konto']);
        $statement->bindValue(':kodPartnera', $dokument['kodPartnera']);
        $statement->bindValue(':vrsDo', $dokument['vrsDo']);
        $statement->bindValue(':broDo', $dokument['broDo']);
        $statement->bindValue(':vKonto', $vezniDokument['konto']);
        $statement->bindValue(':vKodPartnera', $vezniDokument['kodPartnera']);
        $statement->bindValue(':vVrsDo', $vezniDokument['vrsDo']);
        $statement->bindValue(':vBroDo', $vezniDokument['broDo']);
        $statement->bindValue(':iznosVeze', $iznosVeze);
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
    //
    
    update_gk_iznosOtv($dokument['vrsDo'], $dokument['broDo'], $dokument['konto'], $dokument['kodPartnera'], $dokument['iznosOtv']-$iznosVeze);
    
    /*
    Kod veznog dokumenta: 
    uspoređuju se da li su Dugovno/Potrazno  isti za GLAVNI
    i VEZNI. Ako su isti, iznos veze mijenja predznak 
    jer se kod povezivanja uzima uvijek predznak polaznog dokumenta,
    a u vezama nije navedeno polje Dugovno/Potrazno, tako da se
    kod sumiranja po vezama o ovome mora voditi racuna.
     */
    $istiDugujePotrazuje=$dokument['iznosDug']==0 && $vezniDokument['iznosDug']==0 
                      || $dokument['iznosPot']==0 && $vezniDokument['iznosPot']==0;
    if($istiDugujePotrazuje)
        $iznosVeze=-$iznosVeze;
    update_gk_iznosOtv($vezniDokument['vrsDo'], $vezniDokument['broDo'], $vezniDokument['konto'], $vezniDokument['kodPartnera'], $vezniDokument['iznosOtv']-$iznosVeze);
}
function delete_veze($slogVeze) {
    global $db;
    $query = "
        delete from veze
        where konto=:konto and kodPartnera=:kodPartnera and vrsDo=:vrsDo and broDo=:broDo
        and vKonto=:vKonto and vKodPartnera=:vKodPartnera and vVrsDo=:vVrsDo and vBroDo=:vBroDo
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':konto', $slogVeze['konto']);
        $statement->bindValue(':kodPartnera', $slogVeze['kodPartnera']);
        $statement->bindValue(':vrsDo', $slogVeze['vrsDo']);
        $statement->bindValue(':broDo', $slogVeze['broDo']);
        $statement->bindValue(':vKonto', $slogVeze['vKonto']);
        $statement->bindValue(':vKodPartnera', $slogVeze['vKodPartnera']);
        $statement->bindValue(':vVrsDo', $slogVeze['vVrsDo']);
        $statement->bindValue(':vBroDo', $slogVeze['vBroDo']);
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
    //
    $sumaVeza=suma_veza_po_dok($slogVeze['vrsDo'], $slogVeze['broDo'], $slogVeze['konto'], $slogVeze['kodPartnera']);
    update_gk_iznosOtv($slogVeze['vrsDo'], $slogVeze['broDo'], $slogVeze['konto'], $slogVeze['kodPartnera'] , $sumaVeza['otvoreno']);
    
    $sumaVeza=suma_veza_po_dok($slogVeze['vVrsDo'], $slogVeze['vBroDo'], $slogVeze['vKonto'], $slogVeze['vKodPartnera']);
    //$slogVeze2[]=array('vrsDo' => $slogVeze['vVrsDo'], 'broDo' => $slogVeze['vBroDo'], 'konto' => $slogVeze['vKonto'], 'kodPartnera' => $slogVeze['vKodPartnera']);
    update_gk_iznosOtv($slogVeze['vVrsDo'], $slogVeze['vBroDo'], $slogVeze['vKonto'], $slogVeze['vKodPartnera'], $sumaVeza['otvoreno']);

    
}

function get_veze_po_dokumentu($slog, $DVOdo='') {
    global $db;
    $query = " 
select 'glavni' as vrstaVeze, v.konto, v.vrsDo, v.broDo, v.kodPartnera, 
vkonto as kontoVeze, vvrsDo as vrsDoVeze, vd.oznakaDokumenta as oznakaDokumentaVeze, vbroDo as broDoVeze, vkodPartnera as kodPartneraVeze, iznosVeze,
gk.brojTemeljnice, gk.brojStavke, gk.DVO, gk.valuta, gk.iznosDug, gk.iznosPot, gk.iznosOtv
from veze as v
left outer join vrste_dokumenata as vd on vd.vrsDo=v.vvrsDo
left outer join gk_stavke as gk on gk.konto=v.vkonto and gk.kodPartnera=v.vkodPartnera and gk.vrsDo=v.vVrsdo and gk.broDo=v.vbroDo
where v.konto=:konto and v.kodPartnera=:kodPartnera and v.vrsDo=:vrsDo and v.broDo=:broDo
and (gk.DVO<=:DVOdo or trim(:DVOdo)='')
union all
select 'vezni' as vrstaVeze, vkonto, vvrsDo, vbroDo, vkodPartnera,  
v.konto, v.vrsDo, vd.oznakaDokumenta as oznakaDokumentaVeze, v.broDo, v.kodPartnera, iznosVeze ,
gk.brojTemeljnice, gk.brojStavke, gk.DVO, gk.valuta, gk.iznosDug, gk.iznosPot, gk.iznosOtv
from veze as v
left outer join vrste_dokumenata as vd on vd.vrsDo=v.vrsDo
left outer join gk_stavke as gk on gk.konto=v.konto and gk.kodPartnera=v.kodPartnera and gk.vrsDo=v.vrsdo and gk.broDo=v.broDo
where vkonto=:konto and vkodPartnera=:kodPartnera and vvrsDo=:vrsDo and vbroDo=:broDo
and (gk.DVO<=:DVOdo or trim(:DVOdo)='')
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrsDo', $slog['vrsDo']);
        $statement->bindValue(':broDo', $slog['broDo']);
        $statement->bindValue(':konto', $slog['konto']);
        $statement->bindValue(':kodPartnera', $slog['kodPartnera']);
        if(trim($DVOdo)!='') {
            $d1=new DateTime($DVOdo);
            $DVOdo = $d1->format('Y-m-d H:i:s');
        }
        $statement->bindValue(':DVOdo', $DVOdo);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }    
}

function zbroj_veza_po_dok($vrsDo, $broDo, $konto, $kodPartnera, $DVOdo='') {
    global $db;
    $query = " 
/*
kratak opis upita:
sign(v.iznosVeze) - predznak iznosa na stavki veze,
sign(gk.iznosDug+gk.iznosPot) - predznak dug/pot stavke u gk za koju vršimo izračun 
ako ta dva predznaka nisu jednaka radi se o vezi sa storno stavkom i u sumi mora promjeniti predznak
*/
select 
ifnull(sum(sign(v.iznosVeze) * sign(gk.iznosDug+gk.iznosPot)*v.iznosVeze),0) as sumaVeza, 
(gk.iznosDug+gk.iznosPot) - ifnull(sum(sign(v.iznosVeze) * sign(gk.iznosDug+gk.iznosPot)*v.iznosVeze),0) otvoreno,
gk.iznosDug+gk.iznosPot as iznosUgk 
from gk_stavke as gk
left outer join 
(
    select v.*
    from veze as v 
    -- povezujemo se s gk da bismo vidjelistanje na dan 
    left outer join gk_stavke as gk_veze 
    on ((gk_veze.konto=v.konto and gk_veze.kodPartnera=v.kodPartnera and gk_veze.vrsDo=v.vrsDo and gk_veze.broDo=v.broDo)
    or (gk_veze.konto=v.vKonto and gk_veze.kodPartnera=v.vKodPartnera and gk_veze.vrsDo=v.vVrsDo and gk_veze.broDo=v.vBroDo))
    where ((v.konto=:konto and v.kodPartnera=:kodPartnera and v.vrsDo=:vrsDo and v.broDo=:broDo)
    or (vKonto=:konto and vKodPartnera=:kodPartnera and vVrsDo=:vrsDo and vBroDo=:broDo))
    and not (gk_veze.vrsDo=:vrsDo and gk_veze.broDo=:broDo) 
    and (gk_veze.DVO<=:DVOdo or trim(:DVOdo)='')
) as v on
((v.konto=gk.konto and v.kodPartnera=gk.kodPartnera and v.vrsDo=gk.vrsDo and v.broDo=gk.broDo)
or (vKonto=gk.konto and vKodPartnera=gk.kodPartnera and vVrsDo=gk.vrsDo and vBroDo=gk.broDo))
where gk.konto=:konto and gk.kodPartnera=:kodPartnera and gk.vrsDo=:vrsDo and gk.broDo=:broDo
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrsDo', $vrsDo);
        $statement->bindValue(':broDo', $broDo);
        $statement->bindValue(':konto', $konto);
        $statement->bindValue(':kodPartnera', $kodPartnera);
        if(trim($DVOdo)=='')
            $datum=$DVOdo;   
        else 
        {
            $d1=new DateTime($DVOdo);
            $datum = $d1->format('Y-m-d H:i:s');
        }
        $statement->bindValue(':DVOdo', $datum);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }    
    
}
?>
