<?php
function get_kuponi() {
    global $db;
    $query = 'SELECT * FROM kuponi'; 
    try {
        $statement = $db->prepare($query);
        $statement->execute();
        $rate = $statement->fetchAll();
        $statement->closeCursor();
        for ($i = 0; $i < count($rate); $i++) {
            $dd=new DateTime($rate[$i]['valuta']);
            $rate[$i]['valuta']=$dd->format("d.m.Y H:i:s");
        }
        return $rate;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_kupon($proda, $vrsDo, $proIn, $zapis, $broDo, $verzi) {
    global $db;
    $query = 
        'SELECT * FROM kuponi 
        WHERE proda = :proda 
        AND vrsDo = :vrsDo 
        AND proIn = :proIn
	AND zapis = :zapis 
        AND broDo = :broDo 
        AND verzi = :verzi
        ';
    $statement = $db->prepare($query);
    $statement->bindValue(':proda', $proda);
    $statement->bindValue(':vrsDo', $vrsDo);
    $statement->bindValue(':proIn', $proIn);
    $statement->bindValue(':zapis', $zapis);
    $statement->bindValue(':broDo', $broDo);
    $statement->bindValue(':verzi', $verzi);
    $statement->execute();
    $slog = $statement->fetch();
    $statement->closeCursor();
    return $slog;
}

function add_kuponi($proda, $vrsDo, $proIn, $zapis, $broDo, $verzi) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $query = "
        INSERT INTO kuponi
        (
            proda,  
            vrsDo,
            proIn,  
            zapis,
            broDo,
            verzi,
            iskoristeniIznosKupona, 
            datumOtvaranja,
            tkoJeKreirao
        )
        VALUES
        (
            :proda,  
            :vrsDo,
            :proIn,  
            :zapis,
            :broDo,
            :verzi,
            0, 
            NOW(), 
            :email_user 
        )";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':proda', $proda);
        $statement->bindValue(':vrsDo', $vrsDo);
        $statement->bindValue(':proIn', $proIn);
        $statement->bindValue(':zapis', $zapis);
        $statement->bindValue(':broDo', $broDo);
        $statement->bindValue(':verzi', $verzi);
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();
        //return $poreznaGrupa;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function update_kuponi($proda, $vrsDo, $proIn, $zapis, $broDo, $verzi, $iskoristeniIznosKupona) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $query = 
        'UPDATE kuponi
        SET
         iskoristeniIznosKupona = :iskoristeniIznosKupona,
         datumIzmjene = now(),
         tkoJeIzmjenio = :email_user 
        WHERE trim(proda) = trim(:proda) 
        AND trim(vrsDo) = trim(:vrsDo) 
        AND trim(proIn) = trim(:proIn)
        AND trim(zapis) = trim(:zapis) 
        AND broDo = :broDo 
        AND trim(verzi) = trim(:verzi)';
    try {	
        $statement = $db->prepare($query);
        $statement->bindValue(':proda', $proda);
        $statement->bindValue(':vrsDo', $vrsDo);
        $statement->bindValue(':proIn', $proIn);
        $statement->bindValue(':zapis', $zapis);
        $statement->bindValue(':broDo', $broDo);
        $statement->bindValue(':verzi', $verzi);
        $statement->bindValue(':iskoristeniIznosKupona', $iskoristeniIznosKupona);
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $rowCount = $statement->rowCount();
        $statement->closeCursor();
    //	return $rowCount;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
 
}

function delete_kuponi($proda, $vrsDo, $proIn, $zapis, $broDo, $verzi) {
    global $db;
    $query = 
        'DELETE FROM kuponi 
        WHERE trim(proda) = trim(:proda) 
        AND trim(vrsDo) = trim(:vrsDo) 
        AND trim(proIn) = trim(:proIn)
        AND trim(zapis) = trim(:zapis) 
        AND broDo = :broDo 
        AND trim(verzi) = trim(:verzi)';
    try {	
        $statement = $db->prepare($query);
        $statement->bindValue(':proda', $proda);
        $statement->bindValue(':vrsDo', $vrsDo);
        $statement->bindValue(':proIn', $proIn);
        $statement->bindValue(':zapis', $zapis);
        $statement->bindValue(':broDo', $broDo);
        $statement->bindValue(':verzi', $verzi);
        $statement->execute();
        $rowCount = $statement->rowCount();
        $statement->closeCursor();
    //	return $rowCount;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
 
}

function is_kupon($kodRobe='') {
    if(isset($_SESSION['dok_zag']['vrsDo']))
        $vrsDo = $_SESSION['dok_zag']['vrsDo'];
    else 
        $vrsDo = '';
    return $_SESSION['skracenicaFirme']=='din' && trim($vrsDo)=='8' && (strtolower(substr($kodRobe, 0, 5))=='kupon' || $kodRobe=='');
}

function get_pregled_kupona($proda, $datumOd, $datumDo, $kojiKuponi) {
    global $db;
    $query = "  
        SELECT k.proda, k.vrsDo, k.proIn, k.zapis, k.broDo, k.verzi, k.iskoristeniIznosKupona, z.DVO as datumIzdavanja,
        IF(iskoristeniIznosKupona=0, NULL, k.datumIzmjene) AS datumIskoristenja,
        i.broDo AS dokumentIskoristenja
        FROM kuponi as k
        LEFT OUTER JOIN dok_zag as z 
        on z.proda=k.proda and z.vrsDo=k.vrsDo and z.proIn=k.proIn and z.broDo=k.broDo and z.verzi=k.verzi
        LEFT OUTER JOIN dok_stavke as i
        on i.proda=k.proda and i.vezniDokument=k.brodo 
        WHERE (k.proda=:proda OR :proda='0')
        AND z.DVO BETWEEN :datumOd AND :datumDo
        AND (:kojiKuponi='s' OR (:kojiKuponi='i' AND iskoristeniIznosKupona<>0) OR (:kojiKuponi='n' AND iskoristeniIznosKupona=0) )
        ORDER BY k.proda, k.vrsDo, k.proIn, k.zapis, k.broDo, k.verzi
        ";
    $statement = $db->prepare($query);
    $statement->bindValue(':proda', $proda);
    $datum = new DateTime($datumOd);
    $statement->bindValue(':datumOd', $datum->format("Y-m-d H:i:s"));
    $datum = new DateTime($datumDo);
    $statement->bindValue(':datumDo', $datum->format("Y-m-d H:i:s"));
    $statement->bindValue(':kojiKuponi', $kojiKuponi);
    $statement->execute();
    $slog = $statement->fetchAll();
    $statement->closeCursor();
    return $slog;
}
?>