<?php
/*
 * Pozivi funnkicije:
 * $dp = get_doprinosi_porezi();                              - vraća sve doprinose poreze
 * $dp = get_doprinosi_porezi($datumObracuna);                - vraća doprinose poreze koji su aktivni za datumObračuna
 * $dp = get_doprinosi_porezi($datumObracuna, 'naDohodak');  - vraća poreze koji su aktivni za datumObračuna
 * $dp = get_doprinosi_porezi($datumObracuna, 'izPlace');    - vraća doprinosi iz plaće koji su aktivni za datumObračuna
 * $dp = get_doprinosi_porezi($datumObracuna, 'naPlacu');    - vraća doprinosi na plaću koji su aktivni za datumObračuna
 * $danas = new DateTime();
 * $dp = get_doprinosi_porezi($danas->format('d.m.Y'));       - vraća trenutno aktivne doprinose poreze
 * 
 */
function get_doprinosi_porezi($datum='', $izIliNaPlacu='') {
    global $db;
    // u tabeli je popunjen datum vrijediOd , a datum vrijediDo se izvidi(ne postoji u tabeli)
    $query = " 
SELECT d1.*, vrijediDo
FROM doprinosi_porezi as d1
JOIN 
( 
    SELECT 
     d.`vrstaDoprinosaPoreza`, d.`vrijediOd`, 
    IF(NULL, NULL, DATE_SUB(min(d2.`vrijediOd`), INTERVAL 1 DAY)) as vrijediDo
    FROM doprinosi_porezi as d
    LEFT OUTER JOIN doprinosi_porezi AS d2
    ON d.`vrstaDoprinosaPoreza`=d2.`vrstaDoprinosaPoreza` and d.`vrijediOd`< d2.`vrijediOd`
    GROUP BY d.`vrstaDoprinosaPoreza`, d.`vrijediOd`
) AS dDo ON dDo.vrstaDoprinosaPoreza=d1.vrstaDoprinosaPoreza AND dDo.vrijediOd=d1.vrijediOd
WHERE (:datum='' OR :datum between d1.vrijediOd and IFNULL(vrijediDo,'3000-01-01'))
AND (:izIliNaPlacu='' OR d1.izIliNaPlacu=:izIliNaPlacu)
    ";
    if($datum!='') {
        $d = new DateTime($datum);
        $datum=$d->format("Y-m-d");
    }
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':datum', $datum);
        $statement->bindValue(':izIliNaPlacu', $izIliNaPlacu);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

/*
 * Funkcija dohvaća doprinos/porez koji vrijedi za zadani datum
 * Na primjer, ako imamo:
 * vrsta  vrijediOd naziv       stopa     osnovica ...
 * ---------------------------------------------------- 
 * porez1 01.01.2000 Stopa(24%) 24.00000  17500.00 ...
 * porez1 01.01.2019 Stopa(24%) 24.00000  35000.00 ...
 * 
 * poziv: 
 *   $porez=get_doprinosPorez_za_datum('porez1','23.12.2018'):
 * vraća slog:
 * porez1 01.01.2000 Stopa(24%) 24.00000  17500.00 ...
 * a poziv: 
 *   $porez=get_doprinosPorez_za_datum('porez1','15.01.2019'):
 * vraća slog:
 * porez1 01.01.2019 Stopa(24%) 24.00000  35000.00 ...
 */
function get_doprinosPorez_za_datum($vrstaDoprinosaPoreza,$datum) {    
    global $db;
    $query = " 
SELECT d1.*, vrijediDo
FROM doprinosi_porezi as d1
JOIN 
( 
    SELECT 
     d.`vrstaDoprinosaPoreza`, d.`vrijediOd`, 
    IF(NULL, NULL, DATE_SUB(min(d2.`vrijediOd`), INTERVAL 1 DAY)) as vrijediDo
    FROM doprinosi_porezi as d
    LEFT OUTER JOIN doprinosi_porezi AS d2
    ON d.`vrstaDoprinosaPoreza`=d2.`vrstaDoprinosaPoreza` and d.`vrijediOd`< d2.`vrijediOd`
    GROUP BY d.`vrstaDoprinosaPoreza`, d.`vrijediOd`
) AS dDo ON dDo.vrstaDoprinosaPoreza=d1.vrstaDoprinosaPoreza AND dDo.vrijediOd=d1.vrijediOd
WHERE d1.vrstaDoprinosaPoreza=:vrstaDoprinosaPoreza
AND (:datum between d1.vrijediOd and IFNULL(vrijediDo,'3000-01-01'))
    ";
    if($datum!='') {
        $d = new DateTime($datum);
        $datum=$d->format("Y-m-d");
    }
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrstaDoprinosaPoreza', $vrstaDoprinosaPoreza);
        $statement->bindValue(':datum', $datum);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_jedan_doprinosPorez($vrstaDoprinosaPoreza,$vrijediOd) {
    global $db;
    $query = " 
    SELECT *
    FROM doprinosi_porezi 
    WHERE vrstaDoprinosaPoreza=:vrstaDoprinosaPoreza
    AND vrijediOd=:vrijediOd
    ";

    $d = new DateTime($vrijediOd);
    $vrijediOd=$d->format("Y-m-d");
    
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrstaDoprinosaPoreza', $vrstaDoprinosaPoreza);
        $statement->bindValue(':vrijediOd', $vrijediOd);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function add_doprinosi_porezi($slog) {
    global $db;
	$email_user = $_SESSION['admin']['email'];
    $query = " 
        INSERT INTO doprinosi_porezi
        (
         vrstaDoprinosaPoreza,
         nazivDoprinosaPoreza,           
         vrijediOd,
         stopaDoprinosaPoreza,
         izIliNaPlacu,
         osnovica,
         modelPlatitelja,
         pozivNaBrojPlatitelja,
         IBAN,
         modelPrimatelja,
         pozivNaBrojPrimatelja,
         datumIzmjene,
         tkoJeIzmjenio
        )    
        VALUES
        (
         :vrstaDoprinosaPoreza,
         :nazivDoprinosaPoreza,           
         :vrijediOd,
         :stopaDoprinosaPoreza,
         :izIliNaPlacu,
         :osnovica,
         :modelPlatitelja,
         :pozivNaBrojPlatitelja,
         :IBAN,
         :modelPrimatelja,
         :pozivNaBrojPrimatelja,
         NOW(),
         :email_user
        )
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrstaDoprinosaPoreza', $slog['vrstaDoprinosaPoreza']);
        $statement->bindValue(':nazivDoprinosaPoreza', $slog['nazivDoprinosaPoreza']);
        $d = new DateTime($slog['vrijediOd']);
        $statement->bindValue(':vrijediOd', $d->format("Y-m-d"));
        $statement->bindValue(':stopaDoprinosaPoreza', str_replace(',', '.', $slog['stopaDoprinosaPoreza']));
        $statement->bindValue(':izIliNaPlacu', $slog['izIliNaPlacu']);
        $statement->bindValue(':osnovica', str_replace(',', '.', $slog['osnovica']));
        $statement->bindValue(':modelPlatitelja',  $slog['modelPlatitelja']);
        $statement->bindValue(':pozivNaBrojPlatitelja',  $slog['pozivNaBrojPlatitelja']);
        $statement->bindValue(':IBAN',  $slog['IBAN']);
        $statement->bindValue(':modelPrimatelja',  $slog['modelPrimatelja']);
        $statement->bindValue(':pozivNaBrojPrimatelja',  $slog['pozivNaBrojPrimatelja']);
        $statement->bindValue(':email_user', $email_user); 
        $statement->execute();
        $statement->closeCursor();      
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function update_doprinosi_porezi($slog, $stariKljuc) {
    global $db;
	$email_user = $_SESSION['admin']['email'];
    $query = " 
        UPDATE doprinosi_porezi
        SET nazivDoprinosaPoreza = :nazivDoprinosaPoreza,           
            vrijediOd = :vrijediOd,
            stopaDoprinosaPoreza = :stopaDoprinosaPoreza,
            izIliNaPlacu = :izIliNaPlacu,
            osnovica = :osnovica,
            modelPlatitelja = :modelPlatitelja,
            pozivNaBrojPlatitelja = :pozivNaBrojPlatitelja,
            IBAN = :IBAN,
            modelPrimatelja = :modelPrimatelja,
            pozivNaBrojPrimatelja = :pozivNaBrojPrimatelja,
            datumIzmjene = NOW(),
            tkoJeIzmjenio = :email_user
        WHERE vrstaDoprinosaPoreza = :vrstaDoprinosaPoreza_st
        AND vrijediOd = :vrijediOd_st
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':nazivDoprinosaPoreza', $slog['nazivDoprinosaPoreza']);
        $d = new DateTime($slog['vrijediOd']);
        $statement->bindValue(':vrijediOd', $d->format("Y-m-d"));
        $statement->bindValue(':stopaDoprinosaPoreza', str_replace(',', '.', $slog['stopaDoprinosaPoreza']));
        $statement->bindValue(':izIliNaPlacu', $slog['izIliNaPlacu']);
        $statement->bindValue(':osnovica', str_replace(',', '.', $slog['osnovica']));
        $statement->bindValue(':modelPlatitelja',  $slog['modelPlatitelja']);
        $statement->bindValue(':pozivNaBrojPlatitelja',  $slog['pozivNaBrojPlatitelja']);
        $statement->bindValue(':IBAN',  $slog['IBAN']);
        $statement->bindValue(':modelPrimatelja',  $slog['modelPrimatelja']);
        $statement->bindValue(':pozivNaBrojPrimatelja',  $slog['pozivNaBrojPrimatelja']);
        $statement->bindValue(':email_user', $email_user); 
        $statement->bindValue(':vrstaDoprinosaPoreza_st', $stariKljuc['vrstaDoprinosaPoreza']);
        $d = new DateTime($stariKljuc['vrijediOd']);
        $statement->bindValue(':vrijediOd_st', $d->format("Y-m-d"));
        $statement->execute();
        $statement->closeCursor();      
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function delete_doprinosi_porezi($vrstaDoprinosaPoreza, $vrijediOd) {
    global $db;
    $query = "DELETE FROM doprinosi_porezi WHERE vrstaDoprinosaPoreza = :vrstaDoprinosaPoreza AND vrijediOd=:vrijediOd";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrstaDoprinosaPoreza', $vrstaDoprinosaPoreza);
        $d = new DateTime($vrijediOd);
        $statement->bindValue(':vrijediOd', $d->format("Y-m-d"));
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

?>